@@ -21,16 +21,16 @@ use OCP\Util;
  */
 class CalendarReferenceListener implements IEventListener {
 	public function __construct(
-		private CalendarInitialStateService $calendarinitialStateService) {
-		$this->calendarinitialStateService = $calendarinitialStateService;
+		private CalendarInitialStateService $calendarInitialStateService,
+	) {
 	}
 
 	public function handle(Event $event): void {
 		if (!$event instanceof RenderReferenceEvent) {
 			return;
 		}
-		$this->calendarinitialStateService->run();
 
+		$this->calendarInitialStateService->run();
 		Util::addScript(Application::APP_ID, 'calendar-reference');
 	}
 }
